@@ -560,10 +560,15 @@ def get_namespace_and_device(*array_list, remove_none=True, remove_types=(str,))
 
     skip_remove_kwargs = dict(remove_none=False, remove_types=[])
 
-    return (
-        *get_namespace(*array_list, **skip_remove_kwargs),
-        device(*array_list, **skip_remove_kwargs),
-    )
+    xp, is_array_api = get_namespace(*array_list, **skip_remove_kwargs)
+    if is_array_api:
+        return (
+            xp,
+            is_array_api,
+            device(*array_list, **skip_remove_kwargs),
+        )
+    else:
+        return xp, False, None
 
 
 def _expit(X, xp=None):
@@ -836,3 +841,20 @@ def indexing_dtype(xp):
     # TODO: once sufficiently adopted, we might want to instead rely on the
     # newer inspection API: https://github.com/data-apis/array-api/issues/640
     return xp.asarray(0).dtype
+
+
+def _count_nonzero(X, xp, device, axis=None, sample_weight=None):
+    """A variant of `sklearn.utils.sparsefuncs.count_nonzero` for the Array API.
+
+    It only supports 2D arrays.
+    """
+    assert X.ndim == 2
+
+    weights = xp.ones_like(X, device=device)
+    if sample_weight is not None:
+        sample_weight = xp.asarray(sample_weight, device=device)
+        sample_weight = xp.reshape(sample_weight, (sample_weight.shape[0], 1))
+        weights = xp.astype(weights, sample_weight.dtype) * sample_weight
+
+    zero_scalar = xp.asarray(0, device=device, dtype=weights.dtype)
+    return xp.sum(xp.where(X != 0, weights, zero_scalar), axis=axis)
